package
module
Version:
v0.14.1
Opens a new window with list of versions in this module.
Published: Feb 16, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶

go-ptt
Parse Torrent Title
Result Reference
- Audio (
[]string): DTS Lossless, DTS Lossy, Atmos, TrueHD, FLAC, DDP, EAC3, DD, AC3, AAC, PCM, OPUS, HQ, MP3
- BitDepth (
string): 8bit, 10bit, 12bit
- Channels (
[]string): 2.0, 5.1, 7.1, stereo, mono
- Codec (
string): AVC (avc, h264, x264,), HEVC (hevc, h265, x265), MPEG-2 (mgpeg2), DivX (divx, dvix), Xvid (xvid)
- Commentary (
bool)
- Complete (
bool)
- Container (
string): mkv, avi, mp4, wmv, mpg, mpeg
- Convert (
bool)
- Date (
string): YYYY-MM-DD
- Documentary (
bool)
- Dubbed (
bool)
- Edition (
string): Anniversary Edition, Ultimate Edition, Director's Cut, Extended Edition, Collector's Edition, Theatrical, Uncut, IMAX, Diamond Edition, Remastered
- EpisodeCode (
string): 8-character alphanumeric code
- Episodes (
[]int): Array of episode numbers
- Extended (
bool)
- Extension (
string): 3g2, 3gp, avi, flv, mkv, mk3d, mov, mp2, mp4, m4v, mpe, mpeg, mpg, mpv, webm, wmv, ogm, divx, ts, m2ts, iso, vob, sub, idx, ttxt, txt, smi, srt, ssa, ass, vtt, nfo, html
- Group (
string): Release group name
- HDR (
[]string): DV, HDR10+, HDR, SDR
- Hardcoded (
bool)
- Languages (
[]string):
- Special:
multi subs, multi audio, dual audio
- ISO 639-1:
en, ja, ko, zh, zh-tw, fr, es, es-419, pt, it, de, ru, uk, nl, da, fi, sv, no, el, lt, lv, et, pl, cs, sk, hu, ro, bg, sr, hr, sl, hi, te, ta, ml, kn, mr, gu, pa, bn, vi, id, th, ms, ar, tr, he, fa
- Network (
string): Apple TV, Amazon, Netflix, Nickelodeon, Disney, HBO, Hulu, CBS, NBC, AMC, PBS, Crunchyroll, VICE, Sony, Hallmark, Adult Swim, Animal Planet, Cartoon Network
- Proper (
bool)
- Quality (
string):
- Cam:
CAM, TeleSync, TeleCine, SCR
- Web:
WEB, WEB-DL, WEBRip, WEB-DLRip
- Broadcast:
HDTV, HDTVRip, PDTV, TVRip, SATRip
- Physical:
BluRay, BluRay REMUX, REMUX, BRRip, BDRip, UHDRip, HDRip, DVD, DVDRip, PPVRip, R5
- Other:
XviD, DivX
- Region (
string): R0-R9, R2J, PAL, NTSC, SECAM
- ReleaseTypes (
[]string): OAD (ODA),OVA(OAV), ONA,
- Remastered (bool)
- Repack (
bool)
- Resolution (
string): 4k (2160p), 2k (1440p), 1080p, 720p, 576p, 480p, 360p, 240p
- Retail (
bool)
- Seasons (
[]int): Array of season numbers
- Site (
string): Source website/URL
- Size (
string): Size with unit (e.g., 2.3GB)
- Subbed (
bool)
- ThreeD (
string): 3D, 3D HSBS, 3D SBS, 3D HOU, 3D OU
- Title (
string): Cleaned title
- Uncensored (
bool)
- Unrated (
bool)
- Upscaled (
bool)
- Volumes (
[]int): Array of volume numbers
- Year (
string): YYYY or YYYY-YYYY
Acknowledgement
License
Licensed under the MIT License. Check the LICENSE file for details.
Documentation
¶
type Result struct {
Audio []string `json:"audio"`
BitDepth string `json:"bit_depth"`
Channels []string `json:"channels"`
Codec string `json:"codec"`
Complete bool `json:"complete"`
Container string `json:"container"`
Convert bool `json:"convert"`
Date string `json:"date"`
Documentary bool `json:"documentary"`
Dubbed bool `json:"dubbed"`
Edition string `json:"edition"`
EpisodeCode string `json:"episode_code"`
Episodes []int `json:"episodes"`
Extended bool `json:"extended"`
Extension string `json:"extension"`
Group string `json:"group"`
HDR []string `json:"hdr"`
Hardcoded bool `json:"hardcoded"`
Languages []string `json:"languages"`
Network string `json:"network"`
Proper bool `json:"proper"`
Quality string `json:"quality"`
Region string `json:"region"`
ReleaseTypes []string `json:"release_types"`
Remastered bool `json:"remastered"`
Repack bool `json:"repack"`
Resolution string `json:"resolution"`
Retail bool `json:"retail"`
Seasons []int `json:"seasons"`
Site string `json:"site"`
Size string `json:"size"`
Subbed bool `json:"subbed"`
ThreeD string `json:"3d"`
Title string `json:"title"`
Uncensored bool `json:"uncensored"`
Unrated bool `json:"unrated"`
Upscaled bool `json:"upscaled"`
Volumes []int `json:"volumes"`
Year string `json:"year"`
}
Source Files
¶
Directories
¶
cmd
|
|
|
|
|
|
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.